@@ -114,6 +114,7 @@
 #include "common/path-utils.h"
 #include "common/help.h"
 #include "common/parse-utils.h"
+#include "common/string-utils.h"
 #include "common/fsfeatures.h"
 #include "common/device-scan.h"
 #include "common/box.h"
@@ -984,7 +985,8 @@ static int make_convert_data_block_groups(struct btrfs_trans_handle *trans,
 			u64 cur_backup = cur;
 
 			len = min(max_chunk_size,
-				  cache->start + cache->size - cur);
+				  round_up(cache->start + cache->size,
+					   BTRFS_STRIPE_LEN) - cur);
 			ret = btrfs_alloc_data_chunk(trans, fs_info, &cur_backup, len);
 			if (ret < 0)
 				break;
@@ -1272,8 +1274,8 @@ static int do_convert(const char *devname, u32 convert_flags, u32 nodesize,
 	snprintf(subvol_name, sizeof(subvol_name), "%s_saved",
 			cctx.convert_ops->name);
 	key.objectid = CONV_IMAGE_SUBVOL_OBJECTID;
-	key.offset = (u64)-1;
 	key.type = BTRFS_ROOT_ITEM_KEY;
+	key.offset = (u64)-1;
 	image_root = btrfs_read_fs_root(root->fs_info, &key);
 	if (!image_root) {
 		error("unable to create image subvolume");
@@ -1320,8 +1322,7 @@ static int do_convert(const char *devname, u32 convert_flags, u32 nodesize,
 
 	memset(root->fs_info->super_copy->label, 0, BTRFS_LABEL_SIZE);
 	if (convert_flags & CONVERT_FLAG_COPY_LABEL) {
-		__strncpy_null(root->fs_info->super_copy->label,
-				cctx.label, BTRFS_LABEL_SIZE - 1);
+		strncpy_null(root->fs_info->super_copy->label, cctx.label, BTRFS_LABEL_SIZE);
 		printf("Copy label '%s'\n", root->fs_info->super_copy->label);
 	} else if (convert_flags & CONVERT_FLAG_SET_LABEL) {
 		strcpy(root->fs_info->super_copy->label, fslabel);
@@ -1484,8 +1485,8 @@ static int check_convert_image(struct btrfs_root *image_root, u64 ino,
 	int ret;
 
 	key.objectid = ino;
-	key.offset = 0;
 	key.type = BTRFS_EXTENT_DATA_KEY;
+	key.offset = 0;
 
 	ret = btrfs_search_slot(NULL, image_root, &key, &path, 0, 0);
 	/*
@@ -1924,7 +1925,7 @@ int BOX_MAIN(convert)(int argc, char *argv[])
 				packing = 0;
 				break;
 			case 'N':
-				nodesize = parse_size_from_string(optarg);
+				nodesize = arg_strtou64_with_suffix(optarg);
 				break;
 			case 'r':
 				rollback = 1;
@@ -1936,7 +1937,7 @@ int BOX_MAIN(convert)(int argc, char *argv[])
 					"label too long, trimmed to %d bytes",
 						BTRFS_LABEL_SIZE - 1);
 				}
-				__strncpy_null(fslabel, optarg, BTRFS_LABEL_SIZE - 1);
+				strncpy_null(fslabel, optarg, BTRFS_LABEL_SIZE);
 				break;
 			case 'L':
 				copylabel = CONVERT_FLAG_COPY_LABEL;
@@ -1995,7 +1996,7 @@ int BOX_MAIN(convert)(int argc, char *argv[])
 						error("invalid UUID: %s\n", optarg);
 						return 1;
 					}
-					strncpy(fsid, optarg, sizeof(fsid));
+					strncpy_null(fsid, optarg, sizeof(fsid));
 				}
 				break;
 			case GETOPT_VAL_HELP:
