@@ -3,15 +3,15 @@
 # Needs kernel modules: null_blk, configfs and at least 2G of free memory for
 # the devices
 
-source "$TEST_TOP/common"
-
-setup_root_helper
-prepare_test_dev
+source "$TEST_TOP/common" || exit
 
 if ! check_min_kernel_version 5.12; then
 	_not_run "zoned tests need kernel 5.12 and newer"
 fi
 
+setup_root_helper
+prepare_test_dev
+
 nullb="$TEST_TOP/nullb"
 # Create 128M devices with 4M zones, 32 of them
 size=128
@@ -22,7 +22,7 @@ count=10
 declare -a devices
 declare -a names
 
-run_check $SUDO_HELPER "$nullb" setup
+run_mayfail $SUDO_HELPER "$nullb" setup
 if [ $? != 0 ]; then
 	_not_run "cannot setup nullb environment for zoned devices"
 fi
